@@ -1,6 +1,6 @@
 '''cr_security.py: click security checks'''
 #
-# Copyright (C) 2013-2015 Canonical Ltd.
+# Copyright (C) 2013-2016 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,6 +16,10 @@
 
 from __future__ import print_function
 
+from clickreviews.common import (
+    AA_PROFILE_NAME_MAXLEN,
+    AA_PROFILE_NAME_ADVLEN,
+)
 from clickreviews.cr_common import ClickReview, error, open_file_read
 import clickreviews.cr_common as cr_common
 import clickreviews.apparmor_policy as apparmor_policy
@@ -47,6 +51,9 @@ class ClickReviewSecurity(ClickReview):
         ClickReview.__init__(self, fn, "security", peer_hooks=peer_hooks,
                              overrides=overrides)
 
+        if not self.is_click and not self.is_snap1:
+            return
+
         # If local_copy is None, then this will check the server to see if
         # we are up to date. However, if we are working within the development
         # tree, use it unconditionally.
@@ -141,7 +148,7 @@ class ClickReviewSecurity(ClickReview):
         self.security_profiles = dict()
         self.security_apps_profiles = []
 
-        if self.manifest is None and self.is_snap:
+        if self.manifest is None and self.is_snap1:
             for exe_t in ['services', 'binaries']:
                 if exe_t not in self.pkg_yaml:
                     continue
@@ -265,30 +272,19 @@ class ClickReviewSecurity(ClickReview):
 
     def _get_security_manifest(self, app):
         '''Get the security manifest for app'''
-        if self._pkgfmt_type() == "click" or self._pkgfmt_version() == "15.04":
-            if app not in self.manifest['hooks']:
-                error("Could not find '%s' in click manifest" % app)
-            elif 'apparmor' not in self.manifest['hooks'][app]:
-                error("Could not find apparmor hook for '%s' in click manifest" %
-                      app)
-            f = self.manifest['hooks'][app]['apparmor']
-            m = self.security_manifests[f]
-        else:
-            f = app
-            m = self.security_manifests[app]
+        if app not in self.manifest['hooks']:
+            error("Could not find '%s' in click manifest" % app)
+        elif 'apparmor' not in self.manifest['hooks'][app]:
+            error("Could not find apparmor hook for '%s' in click manifest" %
+                  app)
+        f = self.manifest['hooks'][app]['apparmor']
+        m = self.security_manifests[f]
 
         return (f, m)
 
     def _extract_security_profile(self, app):
         '''Extract security profile'''
-        if self._pkgfmt_type() == "click" or self._pkgfmt_version() == "15.04":
-            rel_fn = self.manifest['hooks'][app]['apparmor-profile']
-        else:
-            exe_t, name = app.split('/')
-            for item in self.pkg_yaml[exe_t]:
-                if 'name' in item and item['name'] == name:
-                    rel_fn = item['security-policy']['apparmor']
-                    break
+        rel_fn = self.manifest['hooks'][app]['apparmor-profile']
 
         fn = os.path.join(self.unpack_dir, rel_fn)
         if not os.path.exists(fn):
@@ -308,56 +304,16 @@ class ClickReviewSecurity(ClickReview):
 
     def _get_security_profile(self, app):
         '''Get the security profile for app'''
-        if self._pkgfmt_type() == "click" or self._pkgfmt_version() == "15.04":
-            if app not in self.manifest['hooks']:
-                error("Could not find '%s' in click manifest" % app)
-            elif 'apparmor-profile' not in self.manifest['hooks'][app]:
-                error("Could not find apparmor-profile hook for '%s' in click "
-                      "manifest" % app)
-            f = self.manifest['hooks'][app]['apparmor-profile']
-        else:
-            exe_t, name = app.split('/')
-            for item in self.pkg_yaml[exe_t]:
-                if 'name' in item and item['name'] == name:
-                    f = item['security-policy']['apparmor']
-                    break
+        if app not in self.manifest['hooks']:
+            error("Could not find '%s' in click manifest" % app)
+        elif 'apparmor-profile' not in self.manifest['hooks'][app]:
+            error("Could not find apparmor-profile hook for '%s' in click "
+                  "manifest" % app)
+        f = self.manifest['hooks'][app]['apparmor-profile']
 
         p = self.security_profiles[f]
         return (f, p)
 
-    def _get_policy_versions(self, vendor):
-        '''Get the supported AppArmor policy versions'''
-        if vendor not in self.aa_policy:
-            error("Could not find vendor '%s'" % vendor, do_exit=False)
-            return None
-
-        supported_policy_versions = []
-        for i in self.aa_policy[vendor].keys():
-            supported_policy_versions.append("%.1f" % float(i))
-
-        return sorted(supported_policy_versions)
-
-    def _get_templates(self, vendor, version, aa_type="all"):
-        '''Get templates by type'''
-        templates = []
-        if aa_type == "all":
-            for k in self.aa_policy[vendor][version]['templates'].keys():
-                templates += self.aa_policy[vendor][version]['templates'][k]
-        else:
-            templates = self.aa_policy[vendor][version]['templates'][aa_type]
-
-        return sorted(templates)
-
-    def _has_policy_version(self, vendor, version):
-        '''Determine if has specified policy version'''
-        if vendor not in self.aa_policy:
-            error("Could not find vendor '%s'" % vendor, do_exit=False)
-            return False
-
-        if str(version) not in self.aa_policy[vendor]:
-            return False
-        return True
-
     def _get_highest_policy_version(self, vendor):
         '''Determine highest policy version for the vendor'''
         if vendor not in self.aa_policy:
@@ -366,34 +322,11 @@ class ClickReviewSecurity(ClickReview):
 
         return float(sorted(self.aa_policy[vendor].keys())[-1])
 
-    def _get_policy_groups(self, vendor, version, aa_type="all"):
-        '''Get policy groups by type'''
-        groups = []
-        if vendor not in self.aa_policy:
-            error("Could not find vendor '%s'" % vendor, do_exit=False)
-            return groups
-
-        if not self._has_policy_version(vendor, version):
-            error("Could not find version '%s'" % version, do_exit=False)
-            return groups
-
-        v = str(version)
-        if aa_type == "all":
-            for k in self.aa_policy[vendor][v]['policy_groups'].keys():
-                groups += self.aa_policy[vendor][v]['policy_groups'][k]
-        else:
-            groups = self.aa_policy[vendor][v]['policy_groups'][aa_type]
-
-        return sorted(groups)
-
-    def _get_policy_group_type(self, vendor, version, policy_group):
-        '''Return policy group type'''
-        for t in self.aa_policy[vendor][version]['policy_groups']:
-            if policy_group in self.aa_policy[vendor][version]['policy_groups'][t]:
-                return t
-
     def check_policy_vendor(self):
         '''Check policy_vendor'''
+        if not self.is_click and not self.is_snap1:
+            return
+
         for app in sorted(self.security_apps):
             (f, m) = self._get_security_manifest(app)
             t = 'info'
@@ -405,10 +338,6 @@ class ClickReviewSecurity(ClickReview):
                 s = "policy_vendor '%s' not found" % m['policy_vendor']
             self._add_result(t, n, s)
 
-            if self._pkgfmt_type() == "snap" and \
-                    float(self._pkgfmt_version()) >= 16.04:
-                continue
-
             t = 'info'
             n = self._get_check_name('policy_vendor_matches_framework', extra=f)
             s = "OK"
@@ -418,7 +347,7 @@ class ClickReviewSecurity(ClickReview):
                     framework = self.manifest['framework']
                     # snappy compat manifest supports comma-separated list
                     # for framework
-                    if self.is_snap and ',' in framework:
+                    if self.is_snap1 and ',' in framework:
                         # For now, we know the release framework is appended.
                         # TODO: fix for multiple frameworks
                         framework = framework.split(',')[-1]
@@ -440,6 +369,9 @@ class ClickReviewSecurity(ClickReview):
 
     def check_policy_version(self):
         '''Check policy version'''
+        if not self.is_click and not self.is_snap1:
+            return
+
         for app in sorted(self.security_apps):
             (f, m) = self._get_security_manifest(app)
 
@@ -474,10 +406,6 @@ class ClickReviewSecurity(ClickReview):
                 s = '%s != %s' % (str(m['policy_version']), str(highest))
             self._add_result(t, n, s, l)
 
-            if self._pkgfmt_type() == "snap" and \
-                    float(self._pkgfmt_version()) >= 16.04:
-                continue
-
             t = 'info'
             n = self._get_check_name('policy_version_matches_framework', extra=f)
             s = "OK"
@@ -486,7 +414,7 @@ class ClickReviewSecurity(ClickReview):
                 framework = self.manifest['framework']
                 # snappy compat manifest supports comma-separated list
                 # for framework
-                if self.is_snap and ',' in framework:
+                if self.is_snap1 and ',' in framework:
                     # For now, we know the release framework is appended.
                     # TODO: fix for multiple frameworks
                     framework = framework.split(',')[-1]
@@ -506,6 +434,9 @@ class ClickReviewSecurity(ClickReview):
 
     def check_template(self):
         '''Check template'''
+        if not self.is_click and not self.is_snap1:
+            return
+
         for app in sorted(self.security_apps):
             (f, m) = self._get_security_manifest(app)
 
@@ -556,7 +487,7 @@ class ClickReviewSecurity(ClickReview):
             found = False
             if m['template'] in self._get_templates(vendor, version):
                 found = True
-            elif self.is_snap:
+            elif self.is_snap1:
                 frameworks = []
                 if 'framework' in self.pkg_yaml:
                     frameworks = [x.strip() for x in
@@ -581,6 +512,9 @@ class ClickReviewSecurity(ClickReview):
 
     def check_policy_groups_webapps(self):
         '''Check policy_groups for webapps'''
+        if not self.is_click and not self.is_snap1:
+            return
+
         for app in sorted(self.security_apps):
             (f, m) = self._get_security_manifest(app)
             t = 'info'
@@ -617,6 +551,9 @@ class ClickReviewSecurity(ClickReview):
 
     def check_policy_groups_push_helpers(self):
         '''Check policy groups for push-helpers'''
+        if not self.is_click and not self.is_snap1:
+            return
+
         for app in sorted(self.security_apps):
             (f, m) = self._get_security_manifest(app)
             t = 'info'
@@ -647,6 +584,9 @@ class ClickReviewSecurity(ClickReview):
 
     def check_policy_groups_scopes(self):
         '''Check policy_groups for scopes'''
+        if not self.is_click and not self.is_snap1:
+            return
+
         for app in sorted(self.security_apps):
             (f, m) = self._get_security_manifest(app)
             t = 'info'
@@ -680,6 +620,9 @@ class ClickReviewSecurity(ClickReview):
 
     def check_policy_groups_ubuntu_account_plugin(self):
         '''Check policy_groups for ubuntu-account-plugin template'''
+        if not self.is_click and not self.is_snap1:
+            return
+
         for app in sorted(self.security_apps):
             (f, m) = self._get_security_manifest(app)
 
@@ -719,6 +662,9 @@ class ClickReviewSecurity(ClickReview):
 
     def check_policy_groups(self):
         '''Check policy_groups'''
+        if not self.is_click and not self.is_snap1:
+            return
+
         for app in sorted(self.security_apps):
             (f, m) = self._get_security_manifest(app)
 
@@ -762,7 +708,7 @@ class ClickReviewSecurity(ClickReview):
             self._add_result(t, n, s)
 
             frameworks = []
-            if self.is_snap:
+            if self.is_snap1:
                 if 'framework' in self.pkg_yaml:
                     frameworks = [x.strip() for x in
                                   self.pkg_yaml['framework'].split(',')]
@@ -841,6 +787,9 @@ class ClickReviewSecurity(ClickReview):
 
     def check_ignored(self):
         '''Check ignored fields'''
+        if not self.is_click and not self.is_snap1:
+            return
+
         for app in sorted(self.security_apps):
             (f, m) = self._get_security_manifest(app)
 
@@ -859,6 +808,9 @@ class ClickReviewSecurity(ClickReview):
 
     def check_redflag(self):
         '''Check redflag fields'''
+        if not self.is_click and not self.is_snap1:
+            return
+
         for app in sorted(self.security_apps):
             (f, m) = self._get_security_manifest(app)
 
@@ -881,6 +833,9 @@ class ClickReviewSecurity(ClickReview):
 
     def check_required(self):
         '''Check required fields'''
+        if not self.is_click and not self.is_snap1:
+            return
+
         for app in sorted(self.security_apps):
             (f, m) = self._get_security_manifest(app)
 
@@ -899,6 +854,9 @@ class ClickReviewSecurity(ClickReview):
 
     def check_apparmor_profile(self):
         '''Check apparmor-profile'''
+        if not self.is_click and not self.is_snap1:
+            return
+
         for app in sorted(self.security_apps_profiles):
             (f, p) = self._get_security_profile(app)
 
@@ -908,9 +866,6 @@ class ClickReviewSecurity(ClickReview):
                         '@{APP_PKGNAME}',
                         '@{APP_VERSION}',
                         ]
-            if self._pkgfmt_type() == 'snap' and \
-                    float(self._pkgfmt_version()) > 15.04:
-                searches.append("@{INSTALL_DIR}")
 
             for v in searches:
                 t = 'info'
@@ -1145,9 +1100,10 @@ class ClickReviewSecurity(ClickReview):
         '''Verify click and security yaml are in sync (not including
            override)
         '''
-        if not self.is_snap or \
-                self.pkg_yaml['type'] in self.sec_skipped_types or \
-                float(self._pkgfmt_version()) > 15.04:
+        if not self.is_click and not self.is_snap1:
+            return
+
+        if self.is_click or self.pkg_yaml['type'] in self.sec_skipped_types:
             return
 
         # setup a small dict that is a subset of self.pkg_yaml
@@ -1187,9 +1143,10 @@ class ClickReviewSecurity(ClickReview):
 
     def check_security_yaml_override_and_click(self):
         '''Verify click and security yaml override are in sync'''
-        if not self.is_snap or \
-                self.pkg_yaml['type'] in self.sec_skipped_types or \
-                float(self._pkgfmt_version()) > 15.04:
+        if not self.is_click and not self.is_snap1:
+            return
+
+        if self.is_click or self.pkg_yaml['type'] in self.sec_skipped_types:
             return
 
         for exe_t in ['services', 'binaries']:
@@ -1226,7 +1183,10 @@ class ClickReviewSecurity(ClickReview):
 
     def check_security_yaml_override(self):
         '''Verify security yaml override'''
-        if not self.is_snap:
+        if not self.is_click and not self.is_snap1:
+            return
+
+        if not self.is_snap1:
             return
 
         for exe_t in ['services', 'binaries']:
@@ -1248,7 +1208,7 @@ class ClickReviewSecurity(ClickReview):
                 s = "OK"
                 if 'security-override' not in item:
                     s = "OK (skipping unspecified override)"
-                elif float(self._pkgfmt_version()) < 16.04:
+                else:
                     if 'apparmor' not in item['security-override']:
                         t = 'error'
                         s = "'apparmor' not specified in 'security-override' " + \
@@ -1257,38 +1217,15 @@ class ClickReviewSecurity(ClickReview):
                         t = 'error'
                         s = "'seccomp' not specified in 'security-override' " + \
                             "for '%s'" % app
-                else:
-                    allowed_fields = ['read-paths',
-                                      'write-paths',
-                                      'abstractions',
-                                      'syscalls']
-                    if len(item['security-override'].keys()) == 0:
-                        t = 'error'
-                        s = "nothing specified in 'security-override' " + \
-                            "for '%s'" % app
-                    else:
-                        for f in item['security-override'].keys():
-                            if f not in allowed_fields:
-                                t = 'error'
-                                s = "unknown field '%s' in " % f + \
-                                    "'security-override' for '%s'" % app
 
                 self._add_result(t, n, s)
 
-                # security-override on 16.04 gives direct access to syscalls,
-                # read-paths, etc so it always needs a manual override
-                if 'security-override' in item and \
-                        float(self._pkgfmt_version()) > 15.04:
-                    t = 'error'
-                    n = self._get_check_name('yaml_override_present')
-                    s = "(NEEDS REVIEW) 'security-override' not allowed"
-                    l = 'https://developer.ubuntu.com/en/snappy/guides/security-policy/'
-                    m = True
-                    self._add_result(t, n, s, link=l, manual_review=m)
-
     def check_security_yaml_policy(self):
         '''Verify security yaml policy'''
-        if not self.is_snap:
+        if not self.is_click and not self.is_snap1:
+            return
+
+        if not self.is_snap1:
             return
 
         for exe_t in ['services', 'binaries']:
@@ -1330,7 +1267,10 @@ class ClickReviewSecurity(ClickReview):
 
     def check_security_yaml_combinations(self):
         '''Verify security yaml uses valid combinations'''
-        if not self.is_snap or self.pkg_yaml['type'] in self.sec_skipped_types:
+        if not self.is_click and not self.is_snap1:
+            return
+
+        if not self.is_snap1 or self.pkg_yaml['type'] in self.sec_skipped_types:
             return
 
         for exe_t in ['services', 'binaries']:
@@ -1367,7 +1307,10 @@ class ClickReviewSecurity(ClickReview):
 
     def check_security_template(self):
         '''Check snap security-template'''
-        if not self.is_snap or self.pkg_yaml['type'] in self.sec_skipped_types:
+        if not self.is_click and not self.is_snap1:
+            return
+
+        if not self.is_snap1 or self.pkg_yaml['type'] in self.sec_skipped_types:
             return
 
         for exe_t in ['services', 'binaries']:
@@ -1401,7 +1344,7 @@ class ClickReviewSecurity(ClickReview):
                     continue
                 self._add_result(t, n, s)
 
-                if self._pkgfmt_version() == "15.04":
+                if self.is_snap1:
                     t = 'info'
                     n = self._get_check_name('yaml_security-template_in_manifest', app=app)
                     s = "OK"
@@ -1421,7 +1364,10 @@ class ClickReviewSecurity(ClickReview):
 
     def check_security_caps(self):
         '''Check snap caps'''
-        if not self.is_snap or self.pkg_yaml['type'] in self.sec_skipped_types:
+        if not self.is_click and not self.is_snap1:
+            return
+
+        if not self.is_snap1 or self.pkg_yaml['type'] in self.sec_skipped_types:
             return
 
         for exe_t in ['services', 'binaries']:
@@ -1455,7 +1401,7 @@ class ClickReviewSecurity(ClickReview):
                     continue
                 self._add_result(t, n, s)
 
-                if self._pkgfmt_version() == "15.04":
+                if self.is_snap1:
                     t = 'info'
                     n = self._get_check_name('yaml_caps_in_manifest', app=app)
                     s = "OK"
@@ -1475,8 +1421,7 @@ class ClickReviewSecurity(ClickReview):
 
     def check_template_online_accounts_provider(self):
         '''Check template for online accounts account-provider'''
-        if self._pkgfmt_type() == "snap" and \
-                float(self._pkgfmt_version()) > 15.04:
+        if not self.is_click and not self.is_snap1:
             return
 
         for app in sorted(self.security_apps):
@@ -1493,8 +1438,7 @@ class ClickReviewSecurity(ClickReview):
 
     def check_template_online_accounts_qml_plugin(self):
         '''Check template for online accounts account-qml-plugin'''
-        if self._pkgfmt_type() == "snap" and \
-                float(self._pkgfmt_version()) > 15.04:
+        if not self.is_click and not self.is_snap1:
             return
 
         for app in sorted(self.security_apps):
@@ -1511,19 +1455,12 @@ class ClickReviewSecurity(ClickReview):
 
     def check_apparmor_profile_name_length(self):
         '''Check AppArmor profile name length'''
-        # There are quite a few kernel interfaces that can cause problems with
-        # long profile names. These are outlined in
-        # https://launchpad.net/bugs/1499544. The big issue is that the audit
-        # message must fit within PAGE_SIZE (at least 4096 on supported archs),
-        # so long names could push the audit message to be too big, which would
-        # result in a denial for that rule (but, only if the rule would've
-        # allowed it). Giving a hard-error on maxlen since we know that this
-        # will be a problem. The advisory length is what it is since we know
-        # that compound labels are sometimes logged and so a snappy system
-        # running an app in a snappy container or a QA testbed running apps
-        # under LXC
-        maxlen = 230  # 245 minus a bit for child profiles
-        advlen = 100
+        if not self.is_click and not self.is_snap1:
+            return
+
+        maxlen = AA_PROFILE_NAME_MAXLEN
+        advlen = AA_PROFILE_NAME_ADVLEN
+
         for app in sorted(self.security_apps):
             (f, m) = self._get_security_manifest(app)
             t = 'info'
